# Generated by roxygen2: do not edit by hand

S3method(print,sfcr_mlt)
S3method(sfcr_expand,sfcr_set)
S3method(sfcr_expand,sfcr_shock)
S3method(sfcr_multis,sfcr_mlt)
S3method(sfcr_multis,sfcr_mlt_set)
S3method(sfcr_multis,sfcr_mlt_shock)
S3method(sfcr_set,formula)
S3method(sfcr_set,sfcr_set)
export("%>%")
export(sfcr_baseline)
export(sfcr_dag_blocks)
export(sfcr_dag_blocks_plot)
export(sfcr_dag_cycles)
export(sfcr_dag_cycles_plot)
export(sfcr_expand)
export(sfcr_get_blocks)
export(sfcr_get_matrix)
export(sfcr_matrix)
export(sfcr_matrix_display)
export(sfcr_multis)
export(sfcr_portfolio)
export(sfcr_random)
export(sfcr_sankey)
export(sfcr_scenario)
export(sfcr_set)
export(sfcr_set_index)
export(sfcr_shock)
export(sfcr_validate)
importFrom(Rcpp,sourceCpp)
importFrom(Rdpack,reprompt)
importFrom(expm,`%^%`)
importFrom(magrittr,"%>%")
importFrom(rlang,.data)
useDynLib(sfcr, .registration = TRUE)
